@@ -14,13 +14,13 @@
 #	opacity = opacity of color for interval polygons
 #	intervalCol = transparent color for interval polygons
 #	avgCol = color for mean/median line
-#	start.time = start time to be fed to getRateThroughTimeMatrix
-#	end.time = end time to be fed to getRateThroughTimeMatrix
+#	start.time = start time in time before present to be fed to getRateThroughTimeMatrix
+#	end.time = end time in time before present to be fed to getRateThroughTimeMatrix
 #	node = if supplied, the clade descended from this node will be used.
 #	nodetype = supplied to getRateThroughTimeMatrix
 #	plot = boolean: if TRUE, a plot will be returned, if FALSE, the data for the plot will be returned. 
-#	xticks = number of ticks on the x-axis.
-#	yticks = number of ticks on the y-axis.
+#	xticks = number of ticks on the x-axis, automatically inferred if NULL.
+#	yticks = number of ticks on the y-axis, automatically inferred if NULL.
 #	xlim = vector of length 2 with min and max times for x axis. X axis is time since present, so if plotting till the present, xlim[2]==0. Can also be 'auto'.
 #	ylim = vector of length 2 with min and max rates for y axis. Can also be 'auto'. 
 #	add = boolean: should rates be added to an existing plot
@@ -28,7 +28,7 @@
 #	+ several undocumented args to set plot parameters: mar, cex, xline, yline, etc.
 #	
 
-plotRateThroughTime <- function(ephy, useMedian = TRUE, intervals=seq(from = 0,to = 1,by = 0.01), ratetype = 'auto', nBins = 100, smooth = FALSE, smoothParam = 0.20, opacity = 0.01, intervalCol='blue', avgCol='red',start.time = NULL, end.time = NULL, node = NULL, nodetype='include', plot = TRUE, cex.axis=1, cex.lab=1.3, lwd=3, xline=3.5, yline=3.5, mar=c(6,6,1,1), xticks=5, yticks=5, xlim='auto', ylim='auto',add=FALSE, axis.labels=TRUE) {
+plotRateThroughTime <- function(ephy, useMedian = TRUE, intervals=seq(from = 0,to = 1,by = 0.01), ratetype = 'auto', nBins = 100, smooth = FALSE, smoothParam = 0.20, opacity = 0.01, intervalCol='blue', avgCol='red',start.time = NULL, end.time = NULL, node = NULL, nodetype='include', plot = TRUE, cex.axis=1, cex.lab=1.3, lwd=3, xline=3.5, yline=3.5, mar=c(6,6,1,1), xticks=NULL, yticks=NULL, xlim='auto', ylim='auto',add=FALSE, axis.labels=TRUE) {
 	
 	if (!any(c('bammdata', 'bamm-ratematrix') %in% class(ephy))) {
 		stop("ERROR: Object ephy must be of class 'bammdata' or 'bamm-ratematrix'.\n");
@@ -82,9 +82,15 @@ plotRateThroughTime <- function(ephy, useMedian = TRUE, intervals=seq(from = 0,t
 		ratelabel <- 'net diversification rate';
 	}
 
+	maxTime <- max(rmat$times)
+
+	#remove NaN columns
+	nanCol <- apply(rate, 2, function(x) any(is.nan(x)));
+	rate <- rate[,which(nanCol == FALSE)];
+	rmat$times <- rmat$times[which(nanCol == FALSE)];
+
 	#generate coordinates for polygons
 	rmat$times <- max(rmat$times) - rmat$times;
-	maxTime <- max(rmat$times)
 	if (!is.null(intervals)) {
 		mm <- apply(rate, MARGIN = 2, quantile, intervals);
 
@@ -160,8 +166,18 @@ plotRateThroughTime <- function(ephy, useMedian = TRUE, intervals=seq(from = 0,t
 				yMax <- ylim[2];
 			}
 			plot.window(xlim=c(xMin, xMax), ylim=c(yMin, yMax));
-			axis(at=c(1.3*xMin,seq(xMin,xMax, length.out=xticks+1)), labels = c(1.3*xMin,signif(seq(xMin, xMax, length.out=xticks+1),digits=2)), cex.axis = cex.axis, side = 1);
-			axis(at=c(-0.2,seq(yMin, 1.2*yMax, length.out=yticks+1)), labels = c(-0.2,signif(seq(yMin, 1.2*yMax, length.out=yticks+1),digits=2)), las=1, cex.axis = cex.axis, side = 2);
+			if (is.null(xticks)) {
+				axis(at=c(round(1.2*xMin),axTicks(1)), cex.axis = cex.axis, side = 1);
+			}
+			if (!is.null(xticks)) {
+				axis(at=c(1.2*xMin,seq(xMin,xMax, length.out=xticks+1)), labels = c(1.2*xMin,signif(seq(xMin, xMax, length.out=xticks+1),digits=2)), cex.axis = cex.axis, side = 1);
+			}
+			if (is.null(yticks)) {
+				axis(at=c(-1,axTicks(2)), cex.axis = cex.axis, las = 1, side = 2);
+			}
+			if (!is.null(yticks)) {
+				axis(at=c(-0.2,seq(yMin, 1.2*yMax, length.out=yticks+1)), labels = c(-0.2,signif(seq(yMin, 1.2*yMax, length.out=yticks+1),digits=2)), las=1, cex.axis = cex.axis, side = 2);	
+			}
 			if (axis.labels) {
 				mtext(side = 1, text = 'time before present', line = xline, cex = cex.lab);
 				mtext(side = 2, text = ratelabel, line = yline, cex = cex.lab);
